/* This file was generated by syncqt. */
#ifndef QT_QTDESIGNER_VERSION_H
#define QT_QTDESIGNER_VERSION_H

#define QTDESIGNER_VERSION_STR "5.15.2"

#define QTDESIGNER_VERSION 0x050F02

#endif // QT_QTDESIGNER_VERSION_H
